param(
[switch]$MofUpdate,
[switch]$IEFeatureOff,
[ValidateSet('Computer','Intranet','TrustedSites','Internet','RestrictedSites')]
[string[]]$ZoneAllowList,
[string[]]$SiteAllowList
)

Function CalculateZoneMask($zones)
{
    $zoneMask = 0
    ForEach($zone in $zones)
    {
        $zoneId = 0
        Switch($zone)
        {
            'Computer' { $zoneId = 0 }
            'Intranet' { $zoneId = 1 }
            'TrustedSites' { $zoneId = 2 }
            'Internet' { $zoneId = 3 }
            'RestrictedSites' { $zoneId = 4 }
        }
        $zoneMask = $zoneMask -bor ([math]::pow(2,$zoneId))
    }

    $zoneMask
}

        <#
        IE Site Discovery Enable/Disable script.

        .USAGE
            Powershell needs to be run elevated.
            To run this script by by-passing execution policy please use:
                powershell -ExecutionPolicy Bypass .\IETElemetrySetUp.ps1

            NOTE: This script will FORCE A LOGOFF when ENABLING the feature. After logoff, IE
                  will be ready to collect browsing information.

            Arguments:
                NO ARGUMENTS:   Enables feature for all users on the machine. Forces a logoff at
                                the end.
                -IEFeatureOff:  Disables feature for all users on the machine. Does not clean up
                                already recorded information.
                -MofUpdate:     To force mof file re-compilation. Will also re-enable feature in
                                case it is disabled and force logoff.
                -ZoneAllowList: Comma-separated list of zones for which this feature is enabled.
                                Allowed values: Computer, Intranet, TrustedSites, Internet, 
                                RestrictedSites.
                -SiteAllowList: Comma-separated list of domains for which this feature is 
                                enabled. 

            For additional information on the feature:
                http://technet.microsoft.com/en-us/library/dn833204.aspx


        .NOTES
            IE looks for a registry setting in the HKCU hive for recording browsing information.
            This script updates the registry entry for all SIDs in the HKEY_USERS hive in order
            to enable IE Site Discovery across all users on the machine.
        #>

Try
{
    $SystemInfo = Get-WMIObject -namespace root/cimv2/IETelemetry -query "Select * from IESystemInfo where systemKey = 'SystemKey'" -ea Stop
}
Catch [system.exception]
{
}
Finally
{
    Try
    {
        if($MofUpdate -or !$SystemInfo)
        {
            $path = Split-Path $MyInvocation.MyCommand.Path
            $empty = mofcomp.exe $path\IETelemetry.mof
            $SDDL = "A;;CCLCSWRPWP;;;AU"
            $security = Get-WmiObject -Namespace root/cimv2/IETelemetry -Class __SystemSecurity
            $converter = new-object system.management.ManagementClass Win32_SecurityDescriptorHelper
            $binarySD = @($null)
            $result = $security.PsBase.InvokeMethod("GetSD",$binarySD)
            $outsddl = $converter.BinarySDToSDDL($binarySD[0])
            $newSDDL = $outsddl.SDDL += "(" + $SDDL + ")"
            $WMIbinarySD = $converter.SDDLToBinarySD($newSDDL)
            $WMIconvertedPermissions = ,$WMIbinarySD.BinarySD
            $result = $security.PsBase.InvokeMethod("SetSD",$WMIconvertedPermissions)
            $versionstring = [System.Diagnostics.FileVersionInfo]::GetVersionInfo("C:\Windows\System32\mshtml.dll").FileVersion
            $split = $versionstring.split(".")
            $a = Get-WMIObject -namespace root/cimv2/IETelemetry -query "Select * from IESystemInfo where systemKey = 'SystemKey'"
            $a.IEVer = $split[0]
            $empty = $a.Put()
            echo "IETelemetry.mof Compiled" 
        }
        <#
            The below code updates the HKCU hive and can be used in cases where the main\local user of a
            machine has admin rights AND if the script is run by the user and not by a system account
            via SCCM.
        #>
        if(!$IEFeatureOff)
        {
            if (!(Test-Path 'HKU:\')) 
            {
                New-PSDrive -PSProvider Registry -Name HKU -Root HKEY_USERS
            }            
            Push-Location
            Get-ChildItem -Path HKU:\*\Software\Microsoft\Internet?Explorer -ErrorAction SilentlyContinue | ForEach-Object {
                $empty = New-Item -Path "$($_.PsPath)\WMITelemetry" -force
                Set-Location "$($_.PsPath)\WMITelemetry"
                Set-ItemProperty -Path . -Name Active -Value 1

                if($ZoneAllowList.Length -gt 0)
                {
                    Set-ItemProperty -Path . -Name ZoneAllowList -Value (CalculateZoneMask $ZoneAllowList) -Type DWord
                }

                if($SiteAllowList.Length -gt 0)
                {
                    Set-ItemProperty -Path . -Name SiteAllowList -Value $SiteAllowList -Type MultiString
                }
            }
            Pop-Location
            echo "Forcing logoff. IE will start recording to WMI after re-login"
            shutdown /l
        }
        else
        {
            <#
              Remove entry from current user's HKCU hive
            #>
            if ((Test-Path 'HKCU:\Software\Microsoft\Internet Explorer\WMITelemetry')) 
            {
                Set-Location 'HKCU:\Software\Microsoft\Internet Explorer\WMITelemetry'
                Set-ItemProperty -Path . -Name Active -Value 0
            }
            if (!(Test-Path 'HKU:\')) 
            {
                New-PSDrive -PSProvider Registry -Name HKU -Root HKEY_USERS
            }            
            <#
              Remove entry from all users in the HKEY_USERS hive
            #>
            Push-Location
            Get-ChildItem -Path 'HKU:\*\Software\Microsoft\Internet?Explorer\WMITelemetry' -ErrorAction SilentlyContinue | ForEach-Object {
                Set-Location "$($_.PsPath)"
                Set-ItemProperty -Path . -Name Active -Value 0
            }
            Pop-Location
            echo "IE will no longer record to WMI after logoff and re-login"
        }
    }
    Catch
    {
        write-host "Caught an exception:" -ForegroundColor Red
        write-host "Exception Type: $($_.Exception.GetType().FullName)" -ForegroundColor Red
        write-host "Exception Message: $($_.Exception.Message)" -ForegroundColor Red
    }
}

# SIG # Begin signature block
# MIIj5gYJKoZIhvcNAQcCoIIj1zCCI9MCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCDe8fx4iD7TMx/p
# I/AxJ68GkZshk3HaFXbwYw8bqboWCKCCDYEwggX/MIID56ADAgECAhMzAAABh3IX
# chVZQMcJAAAAAAGHMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjAwMzA0MTgzOTQ3WhcNMjEwMzAzMTgzOTQ3WjB0MQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMR4wHAYDVQQDExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQDOt8kLc7P3T7MKIhouYHewMFmnq8Ayu7FOhZCQabVwBp2VS4WyB2Qe4TQBT8aB
# znANDEPjHKNdPT8Xz5cNali6XHefS8i/WXtF0vSsP8NEv6mBHuA2p1fw2wB/F0dH
# sJ3GfZ5c0sPJjklsiYqPw59xJ54kM91IOgiO2OUzjNAljPibjCWfH7UzQ1TPHc4d
# weils8GEIrbBRb7IWwiObL12jWT4Yh71NQgvJ9Fn6+UhD9x2uk3dLj84vwt1NuFQ
# itKJxIV0fVsRNR3abQVOLqpDugbr0SzNL6o8xzOHL5OXiGGwg6ekiXA1/2XXY7yV
# Fc39tledDtZjSjNbex1zzwSXAgMBAAGjggF+MIIBejAfBgNVHSUEGDAWBgorBgEE
# AYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUhov4ZyO96axkJdMjpzu2zVXOJcsw
# UAYDVR0RBEkwR6RFMEMxKTAnBgNVBAsTIE1pY3Jvc29mdCBPcGVyYXRpb25zIFB1
# ZXJ0byBSaWNvMRYwFAYDVQQFEw0yMzAwMTIrNDU4Mzg1MB8GA1UdIwQYMBaAFEhu
# ZOVQBdOCqhc3NyK1bajKdQKVMFQGA1UdHwRNMEswSaBHoEWGQ2h0dHA6Ly93d3cu
# bWljcm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY0NvZFNpZ1BDQTIwMTFfMjAxMS0w
# Ny0wOC5jcmwwYQYIKwYBBQUHAQEEVTBTMFEGCCsGAQUFBzAChkVodHRwOi8vd3d3
# Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NlcnRzL01pY0NvZFNpZ1BDQTIwMTFfMjAx
# MS0wNy0wOC5jcnQwDAYDVR0TAQH/BAIwADANBgkqhkiG9w0BAQsFAAOCAgEAixmy
# S6E6vprWD9KFNIB9G5zyMuIjZAOuUJ1EK/Vlg6Fb3ZHXjjUwATKIcXbFuFC6Wr4K
# NrU4DY/sBVqmab5AC/je3bpUpjtxpEyqUqtPc30wEg/rO9vmKmqKoLPT37svc2NV
# BmGNl+85qO4fV/w7Cx7J0Bbqk19KcRNdjt6eKoTnTPHBHlVHQIHZpMxacbFOAkJr
# qAVkYZdz7ikNXTxV+GRb36tC4ByMNxE2DF7vFdvaiZP0CVZ5ByJ2gAhXMdK9+usx
# zVk913qKde1OAuWdv+rndqkAIm8fUlRnr4saSCg7cIbUwCCf116wUJ7EuJDg0vHe
# yhnCeHnBbyH3RZkHEi2ofmfgnFISJZDdMAeVZGVOh20Jp50XBzqokpPzeZ6zc1/g
# yILNyiVgE+RPkjnUQshd1f1PMgn3tns2Cz7bJiVUaqEO3n9qRFgy5JuLae6UweGf
# AeOo3dgLZxikKzYs3hDMaEtJq8IP71cX7QXe6lnMmXU/Hdfz2p897Zd+kU+vZvKI
# 3cwLfuVQgK2RZ2z+Kc3K3dRPz2rXycK5XCuRZmvGab/WbrZiC7wJQapgBodltMI5
# GMdFrBg9IeF7/rP4EqVQXeKtevTlZXjpuNhhjuR+2DMt/dWufjXpiW91bo3aH6Ea
# jOALXmoxgltCp1K7hrS6gmsvj94cLRf50QQ4U8Qwggd6MIIFYqADAgECAgphDpDS
# AAAAAAADMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQGEwJVUzETMBEGA1UECBMK
# V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
# IENvcnBvcmF0aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0
# ZSBBdXRob3JpdHkgMjAxMTAeFw0xMTA3MDgyMDU5MDlaFw0yNjA3MDgyMTA5MDla
# MH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMT
# H01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTEwggIiMA0GCSqGSIb3DQEB
# AQUAA4ICDwAwggIKAoICAQCr8PpyEBwurdhuqoIQTTS68rZYIZ9CGypr6VpQqrgG
# OBoESbp/wwwe3TdrxhLYC/A4wpkGsMg51QEUMULTiQ15ZId+lGAkbK+eSZzpaF7S
# 35tTsgosw6/ZqSuuegmv15ZZymAaBelmdugyUiYSL+erCFDPs0S3XdjELgN1q2jz
# y23zOlyhFvRGuuA4ZKxuZDV4pqBjDy3TQJP4494HDdVceaVJKecNvqATd76UPe/7
# 4ytaEB9NViiienLgEjq3SV7Y7e1DkYPZe7J7hhvZPrGMXeiJT4Qa8qEvWeSQOy2u
# M1jFtz7+MtOzAz2xsq+SOH7SnYAs9U5WkSE1JcM5bmR/U7qcD60ZI4TL9LoDho33
# X/DQUr+MlIe8wCF0JV8YKLbMJyg4JZg5SjbPfLGSrhwjp6lm7GEfauEoSZ1fiOIl
# XdMhSz5SxLVXPyQD8NF6Wy/VI+NwXQ9RRnez+ADhvKwCgl/bwBWzvRvUVUvnOaEP
# 6SNJvBi4RHxF5MHDcnrgcuck379GmcXvwhxX24ON7E1JMKerjt/sW5+v/N2wZuLB
# l4F77dbtS+dJKacTKKanfWeA5opieF+yL4TXV5xcv3coKPHtbcMojyyPQDdPweGF
# RInECUzF1KVDL3SV9274eCBYLBNdYJWaPk8zhNqwiBfenk70lrC8RqBsmNLg1oiM
# CwIDAQABo4IB7TCCAekwEAYJKwYBBAGCNxUBBAMCAQAwHQYDVR0OBBYEFEhuZOVQ
# BdOCqhc3NyK1bajKdQKVMBkGCSsGAQQBgjcUAgQMHgoAUwB1AGIAQwBBMAsGA1Ud
# DwQEAwIBhjAPBgNVHRMBAf8EBTADAQH/MB8GA1UdIwQYMBaAFHItOgIxkEO5FAVO
# 4eqnxzHRI4k0MFoGA1UdHwRTMFEwT6BNoEuGSWh0dHA6Ly9jcmwubWljcm9zb2Z0
# LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY1Jvb0NlckF1dDIwMTFfMjAxMV8wM18y
# Mi5jcmwwXgYIKwYBBQUHAQEEUjBQME4GCCsGAQUFBzAChkJodHRwOi8vd3d3Lm1p
# Y3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1Jvb0NlckF1dDIwMTFfMjAxMV8wM18y
# Mi5jcnQwgZ8GA1UdIASBlzCBlDCBkQYJKwYBBAGCNy4DMIGDMD8GCCsGAQUFBwIB
# FjNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2RvY3MvcHJpbWFyeWNw
# cy5odG0wQAYIKwYBBQUHAgIwNB4yIB0ATABlAGcAYQBsAF8AcABvAGwAaQBjAHkA
# XwBzAHQAYQB0AGUAbQBlAG4AdAAuIB0wDQYJKoZIhvcNAQELBQADggIBAGfyhqWY
# 4FR5Gi7T2HRnIpsLlhHhY5KZQpZ90nkMkMFlXy4sPvjDctFtg/6+P+gKyju/R6mj
# 82nbY78iNaWXXWWEkH2LRlBV2AySfNIaSxzzPEKLUtCw/WvjPgcuKZvmPRul1LUd
# d5Q54ulkyUQ9eHoj8xN9ppB0g430yyYCRirCihC7pKkFDJvtaPpoLpWgKj8qa1hJ
# Yx8JaW5amJbkg/TAj/NGK978O9C9Ne9uJa7lryft0N3zDq+ZKJeYTQ49C/IIidYf
# wzIY4vDFLc5bnrRJOQrGCsLGra7lstnbFYhRRVg4MnEnGn+x9Cf43iw6IGmYslmJ
# aG5vp7d0w0AFBqYBKig+gj8TTWYLwLNN9eGPfxxvFX1Fp3blQCplo8NdUmKGwx1j
# NpeG39rz+PIWoZon4c2ll9DuXWNB41sHnIc+BncG0QaxdR8UvmFhtfDcxhsEvt9B
# xw4o7t5lL+yX9qFcltgA1qFGvVnzl6UJS0gQmYAf0AApxbGbpT9Fdx41xtKiop96
# eiL6SJUfq/tHI4D1nvi/a7dLl+LrdXga7Oo3mXkYS//WsyNodeav+vyL6wuA6mk7
# r/ww7QRMjt/fdW1jkT3RnVZOT7+AVyKheBEyIXrvQQqxP/uozKRdwaGIm1dxVk5I
# RcBCyZt2WwqASGv9eZ/BvW1taslScxMNelDNMYIVuzCCFbcCAQEwgZUwfjELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEoMCYGA1UEAxMfTWljcm9z
# b2Z0IENvZGUgU2lnbmluZyBQQ0EgMjAxMQITMwAAAYdyF3IVWUDHCQAAAAABhzAN
# BglghkgBZQMEAgEFAKCCAQ0wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYK
# KwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEINAnWq5L
# nT5ktd+Sj+TlwGwgl/KqJfBqhBbhdomDAeTmMIGgBgorBgEEAYI3AgEMMYGRMIGO
# oEqASABJAG4AdABlAHIAbgBlAHQAIABFAHgAcABsAG8AcgBlAHIAIABTAEQAaQBz
# AGMAbwB2AGUAcgB5ACAAVABvAG8AbABLAGkAdKFAgD5odHRwczovL3d3dy5taWNy
# b3NvZnQuY29tL2VuLXVzL2Rvd25sb2FkL2RldGFpbHMuYXNweD9pZD00NDU3MDAN
# BgkqhkiG9w0BAQEFAASCAQAz5MqFOa6q3MudSHl6B5fXaM8g4OfWZcy4RUX3XWP0
# Zf50qXVyCnhBvZA7+Oj9fVFhic/wxSP3GfeOJYcIdMZzQ7rrnMhp9LowvxU4WsUi
# k8OPsAZjr8rDd6L6OGA8vQUwD9osYLp99pPfij/7ATsAnyra6Tpmw5y16SwCJkT0
# jBnkzHQGa+JWsMRqj29PRqNSUVKuvU/mgiYvKJrgS9y2LsoxjimbTD+gffN+Q7Kb
# fTQI0TFdIsTTGpDH0JHKrEmJf38X5KGD/X07NBYVKmkPOLZ4LRerzoHG7bNboCQO
# /xjNw1uO+4XS5CLkWq2e9BkxWitJM6OM8rICXHZxWEapoYIS5TCCEuEGCisGAQQB
# gjcDAwExghLRMIISzQYJKoZIhvcNAQcCoIISvjCCEroCAQMxDzANBglghkgBZQME
# AgEFADCCAVEGCyqGSIb3DQEJEAEEoIIBQASCATwwggE4AgEBBgorBgEEAYRZCgMB
# MDEwDQYJYIZIAWUDBAIBBQAEIO9ItoSyePYAWmK65MkfuE2TikT29lgjG+X8jMxl
# +EJsAgZfOtZD9u4YEzIwMjAwODI0MjM0MDE4LjkzNVowBIACAfSggdCkgc0wgcox
# CzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRt
# b25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJTAjBgNVBAsTHE1p
# Y3Jvc29mdCBBbWVyaWNhIE9wZXJhdGlvbnMxJjAkBgNVBAsTHVRoYWxlcyBUU1Mg
# RVNOOkFFMkMtRTMyQi0xQUZDMSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFt
# cCBTZXJ2aWNloIIOPDCCBPEwggPZoAMCAQICEzMAAAEWkyLqv7stTeYAAAAAARYw
# DQYJKoZIhvcNAQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0
# b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3Jh
# dGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwHhcN
# MTkxMTEzMjE0MDM0WhcNMjEwMjExMjE0MDM0WjCByjELMAkGA1UEBhMCVVMxEzAR
# BgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1p
# Y3Jvc29mdCBDb3Jwb3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2Eg
# T3BlcmF0aW9uczEmMCQGA1UECxMdVGhhbGVzIFRTUyBFU046QUUyQy1FMzJCLTFB
# RkMxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2UwggEiMA0G
# CSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDQ+Bvz/b3qJ78uPatar4wiUxnCRJTB
# mwgp3jva3J5U7I1wqCpIJPjNC/PaR35UPuVhY3dXRRIvmiKl2n7GnvAfsIAcLvM1
# TbU+N0dY86LaiQiU/JOKStAGjCj4w5X1eB3daoyclIoRqeTtCZIeAmKYnar9lFHn
# 7Rnm5lF6MkeRBwmZMHwar/CDYT+CO5GX+IZrh8Ym7RwdJSJfvybkUTJppzVeeSpp
# 9KphHypvuyfdlW3+W1uIZQmvzviiLZtl25S0IxHRCJZZ8EwTFwtXgDp6uYL3xxtu
# +L+lBvWnWXu9dPY1F4P7GQWrMqfRwDdWL1xzkuMOFj3UvXxG4ciBTeodAgMBAAGj
# ggEbMIIBFzAdBgNVHQ4EFgQU5b9eK7gX6BfNR+UfeTT+V8ghVQswHwYDVR0jBBgw
# FoAU1WM6XIoxkPNDe3xGG8UzaFqFbVUwVgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDov
# L2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvTWljVGltU3RhUENB
# XzIwMTAtMDctMDEuY3JsMFoGCCsGAQUFBwEBBE4wTDBKBggrBgEFBQcwAoY+aHR0
# cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNUaW1TdGFQQ0FfMjAx
# MC0wNy0wMS5jcnQwDAYDVR0TAQH/BAIwADATBgNVHSUEDDAKBggrBgEFBQcDCDAN
# BgkqhkiG9w0BAQsFAAOCAQEANoNq19qpo9sDL+lJ0rx7xd3M3q/33v01JYtSw0eg
# 0EWnKvUVMZy/B/RIoh97TKC3yzymWQBjExR+1SY6c746cZdSBM6t5cjDjO2x6mi2
# t4dwvT3j5ufs5QYs8xrnoZCKLdZSCIY8/SB81eFdypJ130eZeMyEp9GfSM4pEQlM
# +o8ctdLFwDVJVOuDwkO2QP7JZXO64CRKilMbG0mnk9ythSsxvudbVygh7u2xCJI+
# nrEVXMp9cVQn1XMAKG5wT7ympculX/FTen/W9/QOAtkykjbabACBt78TrCDINIrI
# dcjhSyIiVJgBK/4iUo61xfOtdXQhFBR1HIgLVmJZYv9iCDCCBnEwggRZoAMCAQIC
# CmEJgSoAAAAAAAIwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRp
# ZmljYXRlIEF1dGhvcml0eSAyMDEwMB4XDTEwMDcwMTIxMzY1NVoXDTI1MDcwMTIx
# NDY1NVowfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNV
# BAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQG
# A1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAwggEiMA0GCSqGSIb3
# DQEBAQUAA4IBDwAwggEKAoIBAQCpHQ28dxGKOiDs/BOX9fp/aZRrdFQQ1aUKAIKF
# ++18aEssX8XD5WHCdrc+Zitb8BVTJwQxH0EbGpUdzgkTjnxhMFmxMEQP8WCIhFRD
# DNdNuDgIs0Ldk6zWczBXJoKjRQ3Q6vVHgc2/JGAyWGBG8lhHhjKEHnRhZ5FfgVSx
# z5NMksHEpl3RYRNuKMYa+YaAu99h/EbBJx0kZxJyGiGKr0tkiVBisV39dx898Fd1
# rL2KQk1AUdEPnAY+Z3/1ZsADlkR+79BL/W7lmsqxqPJ6Kgox8NpOBpG2iAg16Hgc
# sOmZzTznL0S6p/TcZL2kAcEgCZN4zfy8wMlEXV4WnAEFTyJNAgMBAAGjggHmMIIB
# 4jAQBgkrBgEEAYI3FQEEAwIBADAdBgNVHQ4EFgQU1WM6XIoxkPNDe3xGG8UzaFqF
# bVUwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBDAEEwCwYDVR0PBAQDAgGGMA8GA1Ud
# EwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZWy4/oolxiaNE9lJBb186aGMQwVgYD
# VR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5taWNyb3NvZnQuY29tL3BraS9jcmwv
# cHJvZHVjdHMvTWljUm9vQ2VyQXV0XzIwMTAtMDYtMjMuY3JsMFoGCCsGAQUFBwEB
# BE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9j
# ZXJ0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcnQwgaAGA1UdIAEB/wSBlTCB
# kjCBjwYJKwYBBAGCNy4DMIGBMD0GCCsGAQUFBwIBFjFodHRwOi8vd3d3Lm1pY3Jv
# c29mdC5jb20vUEtJL2RvY3MvQ1BTL2RlZmF1bHQuaHRtMEAGCCsGAQUFBwICMDQe
# MiAdAEwAZQBnAGEAbABfAFAAbwBsAGkAYwB5AF8AUwB0AGEAdABlAG0AZQBuAHQA
# LiAdMA0GCSqGSIb3DQEBCwUAA4ICAQAH5ohRDeLG4Jg/gXEDPZ2joSFvs+umzPUx
# vs8F4qn++ldtGTCzwsVmyWrf9efweL3HqJ4l4/m87WtUVwgrUYJEEvu5U4zM9GAS
# inbMQEBBm9xcF/9c+V4XNZgkVkt070IQyK+/f8Z/8jd9Wj8c8pl5SpFSAK84Dxf1
# L3mBZdmptWvkx872ynoAb0swRCQiPM/tA6WWj1kpvLb9BOFwnzJKJ/1Vry/+tuWO
# M7tiX5rbV0Dp8c6ZZpCM/2pif93FSguRJuI57BlKcWOdeyFtw5yjojz6f32WapB4
# pm3S4Zz5Hfw42JT0xqUKloakvZ4argRCg7i1gJsiOCC1JeVk7Pf0v35jWSUPei45
# V3aicaoGig+JFrphpxHLmtgOR5qAxdDNp9DvfYPw4TtxCd9ddJgiCGHasFAeb73x
# 4QDf5zEHpJM692VHeOj4qEir995yfmFrb3epgcunCaw5u+zGy9iCtHLNHfS4hQEe
# gPsbiSpUObJb2sgNVZl6h3M7COaYLeqN4DMuEin1wC9UJyH3yKxO2ii4sanblrKn
# QqLJzxlBTeCG+SqaoxFmMNO7dDJL32N79ZmKLxvHIa9Zta7cRDyXUHHXodLFVeNp
# 3lfB0d4wwP3M5k37Db9dT+mdHhk4L7zPWAUu7w2gUDXa7wknHNWzfjUeCLraNtvT
# X4/edIhJEqGCAs4wggI3AgEBMIH4oYHQpIHNMIHKMQswCQYDVQQGEwJVUzETMBEG
# A1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWlj
# cm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBP
# cGVyYXRpb25zMSYwJAYDVQQLEx1UaGFsZXMgVFNTIEVTTjpBRTJDLUUzMkItMUFG
# QzElMCMGA1UEAxMcTWljcm9zb2Z0IFRpbWUtU3RhbXAgU2VydmljZaIjCgEBMAcG
# BSsOAwIaAxUAh01b3PJPoIsbWoIM1z76zOzdlkOggYMwgYCkfjB8MQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
# A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQg
# VGltZS1TdGFtcCBQQ0EgMjAxMDANBgkqhkiG9w0BAQUFAAIFAOLujw4wIhgPMjAy
# MDA4MjUwMzEwMDZaGA8yMDIwMDgyNjAzMTAwNlowdzA9BgorBgEEAYRZCgQBMS8w
# LTAKAgUA4u6PDgIBADAKAgEAAgIM/AIB/zAHAgEAAgISGTAKAgUA4u/gjgIBADA2
# BgorBgEEAYRZCgQCMSgwJjAMBgorBgEEAYRZCgMCoAowCAIBAAIDB6EgoQowCAIB
# AAIDAYagMA0GCSqGSIb3DQEBBQUAA4GBAD/clmtZIloYNsJVo/D3Bkc4ZE5YcdEm
# tSrkr0FFKx5LWhgOTO95huP1Q0WST3vfdGoeYf3CK1FP4EuIVrScTlHqOSiU+BVj
# TbFe+oFi7SFvWBvy1MWHG6oQLNX2TNeBIWGbJ9epTAahi3fSTgfhiWrKIKbLfRQk
# exdyjo14WfZ3MYIDDTCCAwkCAQEwgZMwfDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENB
# IDIwMTACEzMAAAEWkyLqv7stTeYAAAAAARYwDQYJYIZIAWUDBAIBBQCgggFKMBoG
# CSqGSIb3DQEJAzENBgsqhkiG9w0BCRABBDAvBgkqhkiG9w0BCQQxIgQgZQx6Fl34
# AI04FmxoBBKMsYeBHw85zGRnL3MTgBZyra4wgfoGCyqGSIb3DQEJEAIvMYHqMIHn
# MIHkMIG9BCCDIpT2pGApCJdcKZshNt20sQ2FjGogyEFoz6Je0sGQyjCBmDCBgKR+
# MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMT
# HU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwAhMzAAABFpMi6r+7LU3mAAAA
# AAEWMCIEIP1PTxGnid2NrFNDdPiqI35OrHel/fBiNETqh0DQ1ZHwMA0GCSqGSIb3
# DQEBCwUABIIBAFaydfjzxIKxHztSXAK7kABvljKEPJxGFwLTYAZzh6bIW0ViOtIz
# oH1macVMot5rM3+c+Vlbo6bcpO/jOD00XFbnBXqBQWXwf4abaN+xQSz6uVOD2q4u
# WSj7wR4bAxrcZ7nLbQOl1BIFzxGlyE00R7C8a/CaO9GlWQDn2z3BzRj2OL21OrQ1
# B8syYJP/ye7Jtj4vAWm11IrDOpDAJa4wrrFqQOibRlLELsU1PafXLbAdNaV8n8eu
# fCxlkwGCyZipUeI/JcLasDIAfPrQG8fmti8WvkdgwooIwZgp4wdXf9p4QThpnpqy
# EDuQF/4trVoIyIIEpc20ENuzT6x8GV+JU0M=
# SIG # End signature block
